@@ -93,6 +93,7 @@
 #define XtNdecimalPosition ((char *) "decimalPosition")
 #define XtNgroup ((char *) "group")
 #define XtNgroupSize ((char *) "groupSize")
+#define XtNplaceOnRail ((char *) "placeOnRail")
 #define XtNdecimalComma ((char *) "decimalComma")
 #define XtNbase ((char *) "base")
 #define XtNsubbase ((char *) "subbase")
@@ -176,6 +177,7 @@
 #define XtCDecimalPosition ((char *) "DecimalPosition")
 #define XtCGroup ((char *) "Group")
 #define XtCGroupSize ((char *) "GroupSize")
+#define XtCPlaceOnRail ((char *) "PlaceOnRail")
 #define XtCDecimalComma ((char *) "DecimalComma")
 #define XtCBase ((char *) "Base")
 #define XtCSubbase ((char *) "Subbase")
@@ -243,6 +245,7 @@ typedef struct {
 #define ACTION_ANCIENT_ROMAN 231
 #define ACTION_LATIN 232
 #define ACTION_GROUP 233
+#define ACTION_PLACE_ON_RAIL 234
 #define ACTION_SIGN 240
 #define ACTION_QUARTER 241
 #define ACTION_QUARTER_PERCENT 242
@@ -328,6 +331,7 @@ typedef struct {
 #define DEFAULT_SHIFT_PERCENT 2
 #define DEFAULT_SHIFT_ANOMALY 2
 #define DEFAULT_GROUP_SIZE 3
+#define DEFAULT_PLACE_ON_RAIL FALSE
 #define SUBDECK_SPACE 1
 #define MAX_MUSEUMS 3
 #define IT 0
